# change working directory to "simulations" folder.

source("Functions/ReadData.R")
source("Functions/calibratedSimulationFunctions.R")
source("Functions/WelfareFunctions.R")
source("Functions/TreatmentAssignmentFunctions.R")

#backcolor="azure2" #background color for plots
#gridcolor="azure1"

fillcolor = "skyblue4"
today = Sys.Date()

printFigures = T
DoHistograms = T

DataList = ReadAllData(printFigures)

#number of replications
MC_replicates = 100000

# parallelize simulations
plan(multiprocess)

#which methods of treatment assignment to simulate, and in which order to display them in the tables
# choices: c("non-adaptive","Thompson","expected Thompson","exploration sampling")
# in the paper: c(4,3,1)
methods = c(4,3,1)
#sample size in multiples of original sample size
# in the paper: c(1)
multiplicities = c(1) #c(.5, 1, 1.5)
#number of waves
# in the paper: c(2,4,10)
wavenumbers = c(2, 4, 10)
#columnames for tables
columnames = paste(wavenumbers, "waves")

# running the simulations
for (Mult in multiplicities) {
  for (application in 1:length(DataList)) {
    applicationData = rep(DataList[application], length(wavenumbers))
    for (i in 1:length(wavenumbers)) {
      applicationData[[i]]$wavesizes = 
        rep(floor(applicationData[[i]]$N * Mult / wavenumbers[i]), wavenumbers[i])
      applicationData[[i]]$waves = wavenumbers[i]
    }
    filename = paste(today, "_CalibratedSimulations_",
                     DataList[[application]]$filename,
                     "_" , Mult, sep = "")
    DesignTable(applicationData, methods, MC_replicates,
                columnames, filename, DoHistograms)
  }
}


