DataToTheta=function(filename, dataname, k, strataVars, outcomename,treatmentname, covariatesnames){
  Data=read_csv(paste("Data/", filename, ".csv", sep=""))
  N=nrow(Data)
  
  treatDummies=paste("treatment",1:k, sep="") #names of treatment variables

  Data=Data %>%
    mutate(treatment=factor(as.matrix(Data[treatDummies])%*%(1:k)))
  
  #average outcomes by treatment alone
  theta=Data %>% 
    group_by(treatment) %>%
    summarize(meanout=mean(outcome), obs=n())
  
  list(filename=filename, dataname=dataname, N=N,
       theta=theta$meanout)
}

# Printout of parameter values
print_one_datafigure=function(DataList) {
    thetas=map(DataList, "theta") #%>% 
    #  map(function(theta) sort(theta, decreasing = T))
    names=map(DataList, "dataname")
    treatments=map(thetas, function(theta) 1:length(theta))
    NoTreatments=map(thetas,length)
    plot_data=tibble(thetas = unlist(thetas),
                     names = unlist(rep(names, NoTreatments)),
                     treatment=factor(unlist(treatments), levels=7:1))
                     
    ggplot(plot_data, aes(x=treatment, y=thetas)) +
      geom_point(color=fillcolor,size=2,alpha=.7) +
      scale_y_continuous(limits=c(0,1)) +
      coord_flip() +
      theme_light() +
      facet_grid(.~as.factor(names)) +
      theme(#panel.background = element_rect(fill = backcolor, colour = NA),
        #panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        axis.ticks.x=element_blank(),
        plot.caption=element_text(size=7)) +
      labs(#title="Calibrated parameter values",
        x="Treatment", y="Average outcome for each treatment")

    ggsave("Figures/calibrated_theta_alternative.pdf", width = 8, height=2)
    
}

ReadAllData=function(printFigures=F){
    #read table of all applications from csv file
    ApplicationTable=read_csv("Data/ApplicationTable.csv")
  
    #read in data for each row of Application table, store output in each element of DataList
    DataList=pmap(ApplicationTable, function(filename, dataname, k, stratavars, outcomename,treatmentname, covariatesnames) #make sure ApplicationTable has these column names
                  DataToTheta(filename, dataname, k, stratavars, outcomename, treatmentname, covariatesnames))
        
    if (printFigures) print_one_datafigure(DataList)
    
    DataList
}
