#dividing N units equally (up to rounding) between k treatments  
EqualAssignment=function(N,k){
  floor((1:N-1)*k/N)+1
}

#D vector based on vector n of assigned units
GivenAssignment=function(n,k){
  sample(rep(1:k, n))
}

#D vector based on shares
ProportionalAssignment = function(Shares, Nt) {
  k=length(Shares)
  n_floor=floor(Nt*Shares) #number of units assigned to each treatment, rounded down
  remainder = Nt*Shares - n_floor
  units_remaining= Nt-sum(n_floor) #remaining number of units to be assigned

  if (units_remaining > 0) {
    Dt= c(rep(1:k, n_floor), # assigning each treatment acoording to rounded down average count
          sample(1:k,size=units_remaining,replace=T, prob=remainder)) #remaining units assigned randomly from remain replicate assignments
  } else {
    Dt= rep(1:k, n_floor)
  }
  sample(Dt)
}

Thompson=function(A,B, Nt) {
  k=length(A)
  thetadraws=sapply(1:k, function(j) rbeta(Nt, A[j], B[j]))
  sapply(1:Nt, function(j) which.max(thetadraws[j,]))
}

ThompsonProbabilities=function(A,B,RR=1000) {
  tabulate(Thompson(A,B,RR), nbins=length(A))/RR
}

# alternative treatment assignment algorithms
Dtchoice=function(A,B,C,Nt, method="optimal"){
  k=length(A)
  if (method=="thompson") {
    # assign treatment in proportion to probability of being best
    Dt=Thompson(A,B, Nt)
  } else if (method=="expectedthompson") {
      alpha=ThompsonProbabilities(A,B)
      Dt=ProportionalAssignment(alpha, Nt)    
  } else if (method=="modifiedthompsonanalytic") {
    alpha=ThompsonProbabilities(A,B)
    if (max(alpha)<1) {
      Shares=alpha*(1-alpha) # Based on stationary distribution for modified Thompson
      Shares=Shares/sum(Shares)
    } else {
      Shares=alpha
    }  
    Dt=ProportionalAssignment(Shares, Nt)  
  }

  Dt
}



