betabinomial = function(n,s,a,b) {
  #probability mass function of the beta-binomial distribution
  #n trials, s successes, beta parameters a,b
  #in logs for numerical reasons
  exp(lgamma(n + 1)-lgamma(s + 1)-lgamma(n - s + 1) +
        lbeta((a + s),(b + n - s)) - lbeta(a,b)) 
}

#requires global variable alpha0 specifying prior precision
betaposterior=function(D,Y){
  A=tapply(Y, D,sum) + alpha0 #posterior parameters, starting with Beta(alpha0,alpha0) (uniform) prior
  B=tapply(1-Y, D,sum) + alpha0
  list(A=A,B=B, theta= A /(A+B))
}

SWF= function(A, B, C){
  #social welfare function for expected average outcome of optimal treatment
  # A,B vectors with a, b parameters of beta distribution
  # C vector with cost of treatments
  max(A /(A+B) - C)
}

PolicyChoice=function(A,B,C){
  # policy choice maximizing expected average outcome of optimal treatment
  # A,B vectors with a, b parameters of beta distribution
  # C vector with cost of treatments
  which.max(A /(A+B) - C)
}

Regret=function(D, #vector of treatments across all waves
                Y, #vector of outcomes across all waves
                C, #treatment cost vector
                theta #true parameter vector
)
{
  k=max(D) #number of treatment arms, assuming we start at 1
  posterior=betaposterior(D,Y)
  d=PolicyChoice(posterior$A,posterior$B,C) # policy chosen given experimental data
  policy_regret=max(theta-C)-theta[d]+C[d] # policy regret - difference in welfare between chosen and optimal option
  in_sample_regret= max(theta-C) - mean(theta[D]-C[D]) #in sample regret - the bandit objective
  c(policy_regret, in_sample_regret)
}


